==> aws-2fa-0.1.1.tar.gz: aws-2fa-0.1.1/setup.py <==
"""
Manage and update aws-cli 2fa creedentials
"""
from setuptools import find_packages, setup

dependencies = [
    'click',
    'awscli',
    'boto3',
]

setup(
    name='aws-2fa',
    version='0.1.1',
    url='https://github.com/zetahernandez/aws-2fa',
    license='BSD',
    author='Zeta Hernandez',
    author_email='zetahernandez@gmail.com',
    description='Manage and update aws-cli 2fa creedentials',
    long_description=__doc__,
    packages=find_packages(exclude=['tests']),
    include_package_data=True,
    zip_safe=False,
    platforms='any',
    install_requires=dependencies,
    entry_points={
        'console_scripts': [
            'aws-2fa = aws_2fa.cli:main',
        ],
    },
    classifiers=[
        # As from http://pypi.python.org/pypi?%3Aaction=list_classifiers
        # 'Development Status :: 1 - Planning',
        # 'Development Status :: 2 - Pre-Alpha',
        # 'Development Status :: 3 - Alpha',
        'Development Status :: 4 - Beta',
        # 'Development Status :: 5 - Production/Stable',
        # 'Development Status :: 6 - Mature',
        # 'Development Status :: 7 - Inactive',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: POSIX',
        'Operating System :: MacOS',
        'Operating System :: Unix',
        'Operating System :: Microsoft :: Windows',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ]
)

==> aws-2fa-0.1.4.tar.gz: aws-2fa-0.1.4/setup.py <==
"""
Manage and update aws-cli 2fa credentials
"""
from setuptools import find_packages, setup

dependencies = [
    'click',
    'awscli',
    'boto3',
]

setup(
    name='aws-2fa',
    version='0.1.4',
    url='https://github.com/zetahernandez/aws-2fa',
    license='BSD',
    author='Zeta Hernandez',
    author_email='zetahernandez@gmail.com',
    description='Manage and update aws-cli 2fa credentials',
    long_description=__doc__,
    packages=find_packages(exclude=['tests']),
    include_package_data=True,
    zip_safe=False,
    platforms='any',
    install_requires=dependencies,
    entry_points={
        'console_scripts': [
            'aws-2fa = aws_2fa.cli:main',
        ],
    },
    classifiers=[
        # As from http://pypi.python.org/pypi?%3Aaction=list_classifiers
        # 'Development Status :: 1 - Planning',
        # 'Development Status :: 2 - Pre-Alpha',
        # 'Development Status :: 3 - Alpha',
        'Development Status :: 4 - Beta',
        # 'Development Status :: 5 - Production/Stable',
        # 'Development Status :: 6 - Mature',
        # 'Development Status :: 7 - Inactive',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: POSIX',
        'Operating System :: MacOS',
        'Operating System :: Unix',
        'Operating System :: Microsoft :: Windows',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ]
)
